      PROGRAM SIMPOWER
C
C SIMPOWER - Written by J.D. Robson, Phase Transformations
C            Group, Department of Materials Science and 
C            Metallurgy, University of Cambridge
C
C PROGRAM FOR SIMULTANEOUS TRANSFORMATIONS
C UP TO SIX PHASES AND THREE CONTROLLING SPECIES
C
C
      IMPLICIT NONE
C
      DOUBLE PRECISION SFEN(6)
      DOUBLE PRECISION NAD(6),XB(6,6),XA(6,6)
      DOUBLE PRECISION XC(6,6),VMAX(6),VDIV(6),V(6)
      DOUBLE PRECISION GMOD(6,6),DV(6),OGMOD(6,6)
      DOUBLE PRECISION DG(6),GRT(6),DVEXT
      DOUBLE PRECISION DVADD(6),VEQ(6)
      DOUBLE PRECISION OMINST(6,6),GROLD(6)
      DOUBLE PRECISION RM(6),DGCHEM(6)
      DOUBLE PRECISION XBINST(6,6),C(6)
      DOUBLE PRECISION DVOLD(6),OMEGA(6,6),NP(6)
      DOUBLE PRECISION DVINC,NR(6),SR(6)
      DOUBLE PRECISION XCI(6),DXCI(6)
      DOUBLE PRECISION SZ(6,0:10000),GREC(6,10000)
      DOUBLE PRECISION NM(6,10000),TN(6,10000),NRT(6,0:10000)
      DOUBLE PRECISION PI, THI, RC, BETA, DT, TK, TINST, T
      DOUBLE PRECISION N, O, DVFLUX, NUTERM, D
C
      INTEGER DS(6), CTYPE(6), FLG(6)
      INTEGER CNT, REG, IN1, OU2
      INTEGER IPHASE, ISPEC, I, II, J, IIJJ
C      
      PI    = 3.141592654
      THI   = 1D-6
      NP(1) = 5d21
      RC    = 1D-11
      BETA  = 50.0D0
      IN1   = 1
      OU2   = 2
C
C
      OPEN(UNIT = IN1,FILE='datain.d')
      OPEN(UNIT = OU2,FILE='dataout.d')
C
C IPHASE - NUMBER OF PHASES TO CALCULATE FOR
C ISPEC  - NUMBER OF RATE CONTROLLING DIFFUSING SPECIES
C
      IPHASE = 2
      ISPEC  = 1
      WRITE(*,*)'PHASE 1 MUST BE CEMENTITE'
      DO 20 I=1,IPHASE
        WRITE(*,*)'PHASE ',I
        WRITE(*,*)'INTERFACIAL ENERGY OF NUCLEUS (J/M^2) ?'
        READ(IN1,*) SFEN(I)
        WRITE(*,*)'SITE DENSITY (RELATIVE TO M3C) ?'
        READ(IN1,*) NAD(I)
        WRITE(*,*)'PHASE TYPE (1 - NEEDLE, 2 - SPHERICAL) ?'
        READ(IN1,*) CTYPE(I)
        WRITE(*,*)'SPECIES CONTROLLING DIFFUSION (1,2,3...) ?'
        READ(IN1,*) DS(I)
        WRITE(*,*)'MAXIMUM VOLUME FRACTION ?'
        READ(IN1,*) VMAX(I)
        WRITE(*,*)'EQUILIBRIUM VOLUME FRACTION ?'
        READ(IN1,*) VEQ(I)
        WRITE(*,*)'DRIVING FORCE FOR FORMING VOLUME V OF PPT (J) ?'
        READ(IN1,*) DG(I)
        WRITE(*,*)'VOLUME FRACTION V (FOR DRIVING FORCE) ?'
        READ(IN1,*) VDIV(I)
        DO 25 II=1,ISPEC
          WRITE(*,*)'SPECIES', II
          WRITE(*,*)'MEAN CONCENTRATION IN ALLOY ?'
          READ(IN1,*) XB(II,I)
          WRITE(*,*)'EQUIM CONCENTRATION OF SPECIES IN PRECIPITATE ?'
          READ(IN1,*) XC(II,I)
          WRITE(*,*)'EQUIM CONCENTRATION OF SPECIES IN MATRIX ?'
          READ(IN1,*) XA(II,I)
25     CONTINUE
20    CONTINUE
      WRITE(*,*)'ENTER STEP SIZE FOR NUMERICAL SUMMATION ?'
      READ(IN1,*) DT
      WRITE(*,*)'ENTER TEMPERATURE FOR CALCULATION (K) ?'
      READ(IN1,*) TK
      CALL DIFCO(D,TK)
C
C ROUTINE FOR OVERALL TRANSFORMATION KINETICS
C
      V(1) = VMAX(1)
      SR(1) = 0.0D0
      SR(2) = 0.0D0
      XCI(1) = XB(1,1)
      XCI(2) = XB(2,1)
C
C IPPF FLAG - SET TO 1 WHEN MAXIMUM VOLUME FRACTION IS REACHED
C
      DO 30 I=2,IPHASE
        GROLD(I) = 1.0D0
        OGMOD(1,I)=2.0D0
        OGMOD(2,I)=2.0D0
        FLG(I) = 0
30    CONTINUE
      CNT = 0
      TINST = 0.0D0
40    J = J + 1.0D0
        T = (10.0D0**(J/10.0D0)) + DT
        REG = 1
50        TINST = TINST + DT
          N = TINST / DT
        CNT = CNT + 1
C
C SR(1) GIVES THE TOTAL SOLUTE REMOVED BY ENRICHMENT AND PRECIPITATION
C
          SR(1) = (V(1)*(XCI(1)-XA(1,1)))
          SR(2) = (V(1)*(XCI(2)-XA(2,1)))
          SR(3) = (V(1)*(XCI(3)-XA(3,1)))
          DO 55 I = 2,IPHASE
             SR(1) = SR(1) + ((V(I)*(XC(1,I)-XA(1,I))))
             SR(2) = SR(2) + ((V(I)*(XC(2,I)-XA(2,I))))
             SR(3) = SR(3) + ((V(I)*(XC(3,I)-XA(3,I))))
55        CONTINUE
          DO 60 I = 1,IPHASE
              IF (FLG(I) .EQ. O) THEN
               IF (XA(1,I) .NE. XB(1,I)) THEN
                 GMOD(1,I) = 1.0D0 - (SR(1)/(XB(1,I)-XA(1,I)))
               ENDIF
               IF (XA(2,I) .NE. XB(2,I)) THEN
                GMOD(2,I) = 1.0D0 - (SR(2)/(XB(2,I)-XA(2,I)))
               ENDIF
               IF (XA(3,I) .NE. XB(3,I)) THEN
                GMOD(3,I) = 1.0D0 - (SR(3)/(XB(3,I)-XA(3,I)))
               ENDIF
C
C SETS GMOD FOR PHASE EQUAL TO THE GMOD VALUE FOR GROWTH CONTROLLING SPECIES
C
                GMOD(1,I)=GMOD(DS(I),I)
                GMOD(2,I)=GMOD(DS(I),I)
                GMOD(3,I)=GMOD(DS(I),I)
              ELSE
                GMOD(1,I)=0.0D0
                GMOD(2,I)=0.0D0
                GMOD(3,I)=0.0D0
              ENDIF
              IF (GMOD(1,I) .LE. 0.0D0) THEN
                 GMOD(1,I) = 0.0D0
                 GMOD(2,I) = 0.0D0
                 IF (FLG(I) .NE. 2) THEN
                    FLG(I) = 1
                 ENDIF
              ENDIF
              OGMOD(1,I)=GMOD(1,I)
              OGMOD(2,I)=GMOD(2,I)
              DGCHEM(I) = GMOD(1,I) * DG(I)
              XBINST(1,I) = (GMOD(1,I) * (XB(1,I)-XA(1,I))) + XA(1,I)
              XBINST(2,I) = (GMOD(2,I) * (XB(2,I)-XA(2,I))) + XA(2,I)
              XBINST(3,I) = (GMOD(3,I) * (XB(3,I)-XA(3,I))) + XA(3,I)
              OMINST(1,I) = GMOD(1,I) * OMEGA(1,I)
              DVADD(I) = 0.0D0
60        CONTINUE
C
C ENRICHMENT OR VOLUME DECREASE OF CEMENTITE
C
          RM(1) = (3.0D0 * V(1))/((4.0D0 * NP(1) * PI))
     &           **(1.0D0/3.0D0)
          DV(1) = 0.0D0
          IF (FLG(1) .EQ. 0) THEN
             DXCI(1) = ((4.0D0 * (D**(0.5)) * (XBINST(1,1)-XA(1,1))
     &            * (DT**(0.5)))/(THI * (PI**(0.5))))
C
C DXCI 2 IS LINKED TO DXCI 1 BY THE RATIO OF COMPONENTS IN EQUIM M3C
C
             DXCI(2) = (0.00836/0.64957) * DXCI(1)
             XCI(1) = XCI(1) + DXCI(1)
             XCI(2) = XCI(2) + DXCI(2)
          ELSE
C
C CEMENTITE DISSOLVES TO PROVIDE SOLUTE TO REMAINING PRECIPITATES
C DIFFUSION FROM CEMENTITE TO PRECIPITATES CONTROLS THE DISSOLUTION OF
C CEMENTITE
C
           DO 70 I = 2,IPHASE
C
C THERE WILL ONLY BE A FLUX FROM CEMENTITE TO ANOTHER PHASE IF XA FOR
C THE CORRECT SPECIES IN THE PRECIPITATING PHASE IS LESS THAN
C XA FOR THE CORRECT SPECIES IN THE DISSOLVING PHASE
C
           IF (XA(1,1) .GT. XA(1,I)) THEN
               DVFLUX = -(4.0D0 * PI * (RM(1)**2.0D0)) *
     &         (4.0D0 * ((NP(1)+NP(I))**(1.0D0/3.0D0))) * D * 
     &         (((XA(1,1) - XA(1,I)) * DT)/(XCI(1)
     &        - XA(1,1)))
               DV(1) = DV(1) + (NP(1) * DVFLUX)
           ENDIF
           DVADD(I) = 0.0D0
70         CONTINUE
          ENDIF
          DXCI(1) =0.0D0
          DXCI(2) =0.0D0
          V(1) = V(1) + DV(1)
          IF (V(1).LT. 0.0D0) V(1) = 0.0D0
C
C PRECIPITATION OR VOLUME DECREASE OF OTHER PHASES
C
          DO 80 I = 2,IPHASE
            IF (FLG(I) .EQ. 0) THEN
             IF (DGCHEM(I) .LT. 0.0D0) THEN
              CALL NURATE(NR(I),DGCHEM(I),SFEN(I),NAD(I),VDIV(I),TK)
             ELSE
              NR(I) = 0.0D0
             ENDIF
              NP(I) = NP(I) + (NR(I) * DT)
C
C ONLY HAVE GROWTH IF COMPOSITION IS DIFFERENT FROM BULK COMPOSITION
C
              IF (XC(DS(I),I) .NE. XA(DS(I),I)) THEN
               CALL GROWTH
     &         (GRT(I),CTYPE(I),XBINST(DS(I),I),XA(DS(I),I),XC(DS(I),I),
     &         D,RC)
              ELSE
               GRT(I) = 0.0D0
              ENDIF
            ENDIF
             CALL SIZE(RM(I),CTYPE(I),GRT(I),V(I),NP(I),BETA)
             CALL CONST(C(I),CTYPE(I),GRT(I),BETA)
C
C FOR SIZE DISTRIBUTION OF PARTICLES NUCLEATING/ GROWING
C 
             DVEXT = 0.0D0
C
C OVERALL KINETICS ROUTINE TO FIND DVEXT(I) 
C
             IF (FLG(I) .EQ. 0) THEN
                TN(I,CNT)=TINST/3600.0D0
                NM(I,CNT)=(NR(I) * DT)
                NRT(I,CNT)=NR(I)
                GREC(I,CNT)=GRT(I)
                DO 87 IIJJ = 0,CNT
                  IF (CTYPE(I) .EQ. 2) THEN
                    NUTERM = (IIJJ**0.5D0)*NRT(I,CNT-IIJJ)
                    DVINC = (C(I)*(DT**(5.0D0/2.0D0))
     &              * NUTERM)
                    IF (IIJJ .LT. CNT) THEN
                    SZ(I,IIJJ)= SZ(I,IIJJ) + 
     &            (0.5D0 * GRT(I) * (((CNT-IIJJ)*DT)**-0.5)
     &             * DT)
                    ENDIF
                    DVEXT = DVEXT + DVINC
                  ENDIF
                  IF (CTYPE(I) .EQ. 1) THEN
C                    write(6,*) '****', CNT, IIJJ
                    NUTERM = (IIJJ**2.0D0) * NRT(I,CNT-IIJJ)
                    DVINC = (C(I) * (DT**4.0D0)
     &              * NUTERM)
                    SZ(I,IIJJ)=SZ(I,IIJJ) + (GRT(I) * DT)
                    DVEXT = DVEXT + DVINC
                  ENDIF
87              CONTINUE
                DV(I) = (1.0D0-(V(1)+V(2)+V(3)+V(4)+V(5)+V(6)))
     &                 * (DVEXT)
             ELSE
C
C OTHER NON-EQUILIBRIUM PHASES DISSOLVE TO PROVIDE SOLUTE TO THE 
C REMAINING PRECIPITATES. DIFFUSION FROM THE DISSOLVING PHASES TO
C THE PRECIPITATING PHASES CONTROLS THE DISSOLUTION RATE
C
                DO 90 II = I+1,IPHASE
C
C THERE WILL ONLY BE A FLUX FROM ONE PHASE TO ANOTHER IF XA FOR
C THE CORRECT SPECIES IN THE PRECIPITATING PHASE IS LESS THAN
C XA FOR THE CORRECT SPECIES IN THE DISSOLVING PHASE
C
C THERE WILL ALSO ONLY BE A FLUX IF THE PHASE IS PRESENT IN THE
C FIRST PLACE - IE COMPOSITION DIFFERS FROM THAT OF BULK
C
               IF(XC(DS(I),I) .NE. XA(DS(I),I)) THEN
                IF (XA(DS(I),I) .GT. XA(DS(I),II)) THEN
                    IF (CTYPE(I) .EQ. 1) THEN
                       DVFLUX = -4.0D0 *
     &                 ((NP(II) + NP(I))**(1.0D0/3.0D0)) *
     &                 (PI/BETA**2.0D0) * 3.0D0 * (RM(I)**2.0D0)
     &                  * ((D * DT * (XA(DS(I),I) - XA(DS(I),II)))
     &                    /(XC(DS(I),I) - XA(DS(I),I)))
                    ENDIF
                    IF (CTYPE(I) .EQ. 2) THEN
                       DVFLUX = - (4.0D0 * PI * (RM(I)**2.0D0)) *
     &                 (4.0D0 * ((NP(II) +NP(I))**(1.0D0/3.0D0)) 
     &                 * D * (XA(DS(I),I) - XA(DS(I),II)) * DT)/
     &                 (XC(DS(I),I) - XA(DS(I),I))
                    ENDIF
                    DV(I) = DV(I) + (NP(I) * DVFLUX)
C
C DONT LET VF FALL BELOW EQUIM VALUE
C
                    IF (V(I) .LE. VEQ(I)) THEN
                      DV(I) =0.0D0
                      DVADD(II) =0.0D0
                    ENDIF
                ENDIF
               ENDIF 
C
C IF XC(DS(I),II) < XA(DS(I),II) THEN DVADD WILL BE PREDICTED -VE. IN REALITY
C THIS CORRESPONDS TO THE SITUATION WHERE DISSOLUTION OF ONE PHASE
C WILL NOT ENCOURAGE THE PRECPITATION OF PHASE II. IN THIS CASE SET
C DVADD TO ZERO
C
              IF (DVADD(II) .LT. 0.0D0) DVADD(II)=0.0D0
              DVADD(II)=0.0D0                  
90              CONTINUE
              ENDIF
              V(I) = V(I) + DV(I) + DVADD(I)
              IF (V(I) .LT. 0.0D0) V(I) = 0.0D0
              IF (V(I) .GT. VMAX(I)) THEN
                 V(I) = VMAX(I)
                 GRT(I) = 0.0D0
                 NR(I) = 0.0D0
                 IF (FLG(I) .NE. 2) THEN
                   FLG(I) = 1
                 ENDIF
              ENDIF
              IF (GRT(I) .GT. 0.0D0) GROLD(I) = GRT(I)
              DVOLD(I) = DV(I)
              DV(I) = 0.0D0
              IF (FLG(I) .EQ. 1) THEN
                WRITE(*,*)'PRECIPITATION OF PHASE COMPLETE FOR PHASE ',I
                FLG(I) = 2
              ENDIF
80        CONTINUE
          REG = 0
          IF (FLG(1) .EQ. 1) THEN
             WRITE(*,*)'CEMENTITE ENRICHMENT COMPLETE'
             FLG(1) = 2
          ENDIF
          IF (TINST .GE. T) THEN
C
C FOR EXTRA PHASES, ADD VOLUMES TO WRITE STATEMENT
C
            WRITE(*,200) TINST/3600.0D0,V(1),V(2)
            WRITE(OU2,200) TINST/3600.0D0,V(1),V(2)
             GOTO 40
          ELSE
             IF ((GMOD(1,1) .EQ. 0.0D0) .AND. 
     &           (GMOD(1,2) .EQ. 0.0D0)
     &           .AND. (GMOD(1,3) .EQ. 0.0D0)
     &           .AND. (GMOD(1,4) .EQ. 0.0D0)
     &           .AND. (GMOD(1,5) .EQ. 0.0D0)) THEN
                WRITE(*,*)'**ALL TRANSFORMATIONS COMPLETE**'
             WRITE(*,200) TINST/3600.0D0,V(1),V(2),V(3),V(4),
     &          V(5),GMOD(1,1),GMOD(1,2),GMOD(1,3),GMOD(1,4),GMOD(1,5)
                STOP
              ELSE
                GOTO 50
              ENDIF
      ENDIF
C
      CLOSE(IN1)
      CLOSE(OU2)
      STOP
200   FORMAT(3D12.5)
      END
C
C***********************************************************
C
C CALCULATES CONSTANT IN KINETICS EQUATION FOR CORRECT
C PARTICLE TYPE
C
      SUBROUTINE CONST(C,CTYPE,GRT,BETA)
      IMPLICIT NONE
      DOUBLE PRECISION C, GRT, BETA, PI
      INTEGER CTYPE
      PI = 3.141592654
      IF (CTYPE .EQ. 1) THEN
          C = (3.0D0 * (GRT**3.0D0) * PI)/(4.0D0 * (BETA **2.0D0))
      ENDIF
      IF (CTYPE .EQ. 2) THEN
          C = (3.0D0/2.0D0) * PI * (GRT **3.0D0)
      ENDIF
      RETURN
      END
C
C***********************************************************
C
C CALLS SUBROUTINE FOR GROWTH DEPENDING ON PARTICLE TYPE
C
      SUBROUTINE GROWTH(GRT,CTYPE,XB,XA,XC,D,RC)
      IMPLICIT NONE
      DOUBLE PRECISION XA, XB, XC
      DOUBLE PRECISION D, GRT, RC
      INTEGER CTYPE
      IF (CTYPE .EQ. 1) THEN
         CALL LINEARGROWTH (GRT,XA,XC,XB,D,RC)
      ENDIF
      IF (CTYPE .EQ. 2) THEN
         CALL PARABOLGROWTH(GRT,XB,XA,XC,D)
      ENDIF
      RETURN
      END
C
C***********************************************************
C
C CALCULATES THE GROWTH RATE FOR LINEAR GROWTH (I.E. NEEDLES)
C
      SUBROUTINE LINEARGROWTH(GR,XA,XC,XB,D,RC)
      IMPLICIT NONE
      DOUBLE PRECISION XA, XB, XC
      DOUBLE PRECISION D, GR, RC, OMEGA
      OMEGA = (XB - XA)/(XC - XA)
      GR = (D * OMEGA)/(4 * RC)
      RETURN
      END
C
C***********************************************************
C
C CALCULATES THE GROWTH CONSTANT (ALPHA3) FOR PARABOLLIC GROWTH
C
      SUBROUTINE PARABOLGROWTH(GC,XB,XA,XC,D)
      IMPLICIT NONE
      DOUBLE PRECISION XA, XB, XC
      DOUBLE PRECISION ALPHA, D, GC, OMEGA
      OMEGA = (XB - XA)/(XC - XA)
C
C 'NATURAL' GROWTH PARAMETER (P. 488 CHRISTIAN)
C
      ALPHA = (2.0D0**(0.5D0)) * ((XB - XA) ** (0.5D0))
     & / ((XC - XB) ** (0.5D0))
      GC = ALPHA * (D**(0.5D0))
      RETURN
      END
C
C***********************************************************
C
C CALCULATES AVERAGE PARTICLE SIZES
C
      SUBROUTINE SIZE(RM,CTYPE,GRT,V,NP,BETA)
      IMPLICIT NONE
      DOUBLE PRECISION BETA, GRT, NP, PI, RM, V
      INTEGER CTYPE
      PI = 3.141592654
      IF ((V .EQ. 0.0D0) .OR. (NP .EQ. 0.0D0)) THEN
         RM = 0.0D0
      ELSE
        IF (CTYPE .EQ. 1) THEN
          RM = (((BETA**2.0D0) * V)/(PI * NP)) ** (1.0D0/3.0D0)
        ENDIF
        IF (CTYPE .EQ. 2) THEN
          RM =((3.0D0 * V)/(4.0D0 * NP * PI)) ** (1.0D0/3.0D0)
        ENDIF
      ENDIF
      RETURN
      END
C
C***********************************************************
C
C CALCULATES NUCLEATION RATE
C
       SUBROUTINE NURATE(NR1,DGCHEM,SFEN1,NAD1,VMAX,TK)
       IMPLICIT NONE
       DOUBLE PRECISION DGCHEM, NR1, SFEN1, NAD1, VMAX, TK
       DOUBLE PRECISION K, NA, H, SHAPE, DGVOL, ACTIVE, PI
       DOUBLE PRECISION NUSITES, N1, DGCRIT1, EPENT1, CONST1
C
       K  = 1.380662D-23
       NA = 6.022045D23
       H  = 6.626176D-34
       SHAPE  = 1.0D0
       DGVOL  = (DGCHEM/VMAX) * 1.437D5
       ACTIVE = (240.0D3/2.0D0)/NA
       PI = 3.141592654
       CALL TSITES(NUSITES,TK)
       N1 = NAD1 * NUSITES
       DGCRIT1 = (16.0D0*PI*((SFEN1*SHAPE)**3.0D0))/
     &  (3.0D0*(DGVOL**2.0D0))
       EPENT1 = -(DGCRIT1 + ACTIVE)/(K * TK)
       CONST1 = (N1 * K * TK)/H
       NR1 = CONST1 * DEXP(EPENT1)
       RETURN
       END
C
C***********************************************************
C
C CALCULATES THE TOTAL NUMBER OF SITES FOR NUCLEATION FOR
C M3C. THIS IS SCALED TO GIVE THE NUMBER OF SITES FOR OTHER
C PRECIPITATES
C
      SUBROUTINE TSITES(NUSITES,TK)
      IMPLICIT NONE
      DOUBLE PRECISION PI, NUSITES, TK, RIN
C
      PI = 3.141592654
         RIN = (2.26D0 - (6.4D-3 * TK) + (4.6D-6 * (TK**2)))
     &         * 1D-21
C        NUSITES = 1.0D0/((4.0D0/3.0D0) * PI * RIN)
       NUSITES = 5.488D21
      RETURN
      END
C
C***********************************************************
C
C  CALCULATES DIFFUSION COEFFICIENT OF CR IN FE
C
      SUBROUTINE DIFCO(D,TK)
      IMPLICIT NONE
      DOUBLE PRECISION D, D0, Q, R, TK
C
          D0 = 1.5D-04
          Q = 240D03
          R = 8.314408694
          D = D0 * DEXP(-Q/(R*TK))
      RETURN
      END
C
C***********************************************************
C
C  USER INPUT [OPTIONAL]
C
      SUBROUTINE USER(ISTENO,INSTEELS,TK,IN2)
      IMPLICIT NONE
      DOUBLE PRECISION TC, TK
      INTEGER IIS, IN2, IOPT, ISTENO, INSTEELS
      CHARACTER*20 STEEL
C
      WRITE(*,*)'** SIMULTANEOUS TRANSFORMATIONS PROGRAM **'
      WRITE(*,*)
      WRITE(*,*)'DATA ARE AVAILABLE FOR THE FOLLOWING STEEL(S)'
      WRITE(*,*)
C
      READ(IN2,*) INSTEELS
      DO 5 IIS = 1,INSTEELS
         READ(IN2,51) STEEL
         WRITE(*,*) IIS,'-',STEEL
5     CONTINUE
51    FORMAT (A20)
      WRITE(*,*)
      WRITE(*,*)'SELECT STEEL TO USE FOR CALCULATIONS'
52      READ(*,*) ISTENO
      IF ((ISTENO .LT. 1) .OR. (ISTENO .GT. INSTEELS)) THEN
         WRITE(*,*)'**OUT OF RANGE, ENTER NEW STEEL NUMBER'
         GOTO 52
      ENDIF
53    WRITE(*,*)'WHAT TEMPERATURE FOR CALCULATIONS (500-800 degC) ?'
      READ(*,*) TC
      IF ((TC .LT. 500.0) .OR. (TC .GT. 800.0)) THEN
         WRITE(*,*)'**TEMPERATURE OUT OF RANGE, SELECT AN OPTION'
         WRITE(*,*)
         WRITE(*,*)'1-PROCEED, RESULTS LIKELY TO BE UNRELIABLE'
         WRITE(*,*)'2-ENTER A DIFFERENT TEMPERATURE'
         READ(*,*) IOPT
         IF (IOPT .NE. 1) GOTO 53
      ENDIF
      TK = TC + 273.0D0
      RETURN
      END
C
C***********************************************************
C
C  CALCULATES COMPOSITIONS/FREE ENERGIES FROM LINE FIT
C
      SUBROUTINE LINECALC(Y,M1,M2,C1,C2,TMAX,TK)
      IMPLICIT REAL*8(A-H,K-Z),INTEGER(I,J)
      IF (TK .GE. TMAX) THEN
         Y = (M2 * TK) + C2
      ELSE
         Y = (M1 * TK) + C1
      ENDIF
      RETURN
      END
